
TODO_66_66_75_78: Split `arg` to `prop` concepts:
*   `arg` is about command line input
*   `prop` is about search, envelopes, data backend

We map `arg` from command line to `prop` for search.

Split "arg" group of concepts (`arg_value`, `arg_type`) and "prop" group of concepts (`prop_value`, `prop_type`):
*   `command_line` args are mapped to `data_envelope` props and almost identical
*   BUT: they are not naturally/intuitively inter-change-able as `data_envelope` properties are hardly `command_line` arguments.
*   Maybe write doc on bounded contexts? Add dictionaries (ubiquitous language) per bash, client, server, data backend?

See also:
*   FS_53_81_66_18: types and classes
